#ifndef __MAVSDK_H__
#define __MAVSDK_H__

#ifdef __cplusplus
extern "C" {
#endif
#include <stdint.h>
// Connexion management functions
int mavsdk_start(const char * url, const char * log_file, int timeout,
                 void (*publishCoordinates)(double, double, float));
int mavsdk_stop(void);
int mavsdk_reboot(void);

// Flight state management functions
int mavsdk_arm(void);
int mavsdk_doParachute(int param);
int mavsdk_loiter(double radius);
int mavsdk_land(void);
int mavsdk_takeOff(void);
int mavsdk_takeOffAndWait(void);

// Flight management functions
int mavsdk_doReposition(double la, double lo, double a, double y);
int mavsdk_loiterUnlimited(double radius, double la, double lo, double a);
int mavsdk_setAirspeed(double airspeed);
int mavsdk_setAltitude(double altitude);
int mavsdk_setTargetAltitude(double a);
int mavsdk_setTargetCoordinates(double la, double lo, double a, double y);
int mavsdk_setTargetCoordinatesXYZ(double x, double y, double z);
int mavsdk_setTargetLatLong(double la, double lo);

// Information functions
double mavsdk_getAltitude(void);
double mavsdk_getInitialAltitude(void);
double mavsdk_getInitialLatitude(void);
double mavsdk_getInitialLongitude(void);
double mavsdk_getLatitude(void);
double mavsdk_getLongitude(void);
double mavsdk_getPitch(void);
double mavsdk_getRoll(void);
double mavsdk_getTakeOffAltitude(void);
double mavsdk_getYaw(void);
int mavsdk_healthAllOk(void);
int mavsdk_landed(void);
#ifdef __cplusplus
}
#endif

#endif /* __MAVSDK_H__ */
